# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: epl/protobuf/naip.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from epl.protobuf import query_pb2 as epl_dot_protobuf_dot_query__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='epl/protobuf/naip.proto',
  package='epl.protobuf',
  syntax='proto3',
  serialized_options=_b('\n\020com.epl.protobufB\tNaipProtoP\001Z+github.com/geo-grpc/api/golang/epl/protobuf\242\002\004NPPB'),
  serialized_pb=_b('\n\x17\x65pl/protobuf/naip.proto\x12\x0c\x65pl.protobuf\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18\x65pl/protobuf/query.proto\"R\n\x0eNaipProperties\x12\x30\n\x0csrc_img_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06usgsid\x18\x02 \x01(\t\"n\n\x0bNaipRequest\x12\x34\n\x0esrc_image_date\x18\x01 \x01(\x0b\x32\x1c.epl.protobuf.TimestampField\x12)\n\x06usgsid\x18\x02 \x01(\x0b\x32\x19.epl.protobuf.StringFieldBS\n\x10\x63om.epl.protobufB\tNaipProtoP\x01Z+github.com/geo-grpc/api/golang/epl/protobuf\xa2\x02\x04NPPBb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,epl_dot_protobuf_dot_query__pb2.DESCRIPTOR,])




_NAIPPROPERTIES = _descriptor.Descriptor(
  name='NaipProperties',
  full_name='epl.protobuf.NaipProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_img_date', full_name='epl.protobuf.NaipProperties.src_img_date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usgsid', full_name='epl.protobuf.NaipProperties.usgsid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=182,
)


_NAIPREQUEST = _descriptor.Descriptor(
  name='NaipRequest',
  full_name='epl.protobuf.NaipRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_image_date', full_name='epl.protobuf.NaipRequest.src_image_date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usgsid', full_name='epl.protobuf.NaipRequest.usgsid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=294,
)

_NAIPPROPERTIES.fields_by_name['src_img_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NAIPREQUEST.fields_by_name['src_image_date'].message_type = epl_dot_protobuf_dot_query__pb2._TIMESTAMPFIELD
_NAIPREQUEST.fields_by_name['usgsid'].message_type = epl_dot_protobuf_dot_query__pb2._STRINGFIELD
DESCRIPTOR.message_types_by_name['NaipProperties'] = _NAIPPROPERTIES
DESCRIPTOR.message_types_by_name['NaipRequest'] = _NAIPREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NaipProperties = _reflection.GeneratedProtocolMessageType('NaipProperties', (_message.Message,), dict(
  DESCRIPTOR = _NAIPPROPERTIES,
  __module__ = 'epl.protobuf.naip_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.NaipProperties)
  ))
_sym_db.RegisterMessage(NaipProperties)

NaipRequest = _reflection.GeneratedProtocolMessageType('NaipRequest', (_message.Message,), dict(
  DESCRIPTOR = _NAIPREQUEST,
  __module__ = 'epl.protobuf.naip_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.NaipRequest)
  ))
_sym_db.RegisterMessage(NaipRequest)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from epl.protobuf import geometry_pb2 as epl_dot_protobuf_dot_geometry__pb2


class GeometryServiceStub(object):
  """
  gRPC Interfaces for working with geometry operators
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GeometryOperationUnary = channel.unary_unary(
        '/epl.protobuf.GeometryService/GeometryOperationUnary',
        request_serializer=epl_dot_protobuf_dot_geometry__pb2.GeometryRequest.SerializeToString,
        response_deserializer=epl_dot_protobuf_dot_geometry__pb2.GeometryResponse.FromString,
        )
    self.GeometryOperationBiStream = channel.stream_stream(
        '/epl.protobuf.GeometryService/GeometryOperationBiStream',
        request_serializer=epl_dot_protobuf_dot_geometry__pb2.GeometryRequest.SerializeToString,
        response_deserializer=epl_dot_protobuf_dot_geometry__pb2.GeometryResponse.FromString,
        )
    self.GeometryOperationBiStreamFlow = channel.stream_stream(
        '/epl.protobuf.GeometryService/GeometryOperationBiStreamFlow',
        request_serializer=epl_dot_protobuf_dot_geometry__pb2.GeometryRequest.SerializeToString,
        response_deserializer=epl_dot_protobuf_dot_geometry__pb2.GeometryResponse.FromString,
        )
    self.FileOperationBiStreamFlow = channel.stream_stream(
        '/epl.protobuf.GeometryService/FileOperationBiStreamFlow',
        request_serializer=epl_dot_protobuf_dot_geometry__pb2.FileRequestChunk.SerializeToString,
        response_deserializer=epl_dot_protobuf_dot_geometry__pb2.GeometryResponse.FromString,
        )


class GeometryServiceServicer(object):
  """
  gRPC Interfaces for working with geometry operators
  """

  def GeometryOperationUnary(self, request, context):
    """Execute a single blocking geometry operation
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GeometryOperationBiStream(self, request_iterator, context):
    """stream in operator requests and get back a stream of results
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GeometryOperationBiStreamFlow(self, request_iterator, context):
    """manual flow control bi-directional stream. example
    go shouldn't use this because of https://groups.google.com/forum/#!topic/grpc-io/6_B46Oszb4k ?
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def FileOperationBiStreamFlow(self, request_iterator, context):
    """Maybe a cut operation that returns a lot of different geometries? for now, this is not implemented.
    rpc GeometryOperationServerStream(epl.protobuf.GeometryRequest) returns (stream epl.protobuf.GeometryResponse) {}

    Maybe something like a union operation. for now, this is not implemented.
    rpc GeometryOperationClientStream(stream epl.protobuf.GeometryRequest) returns (epl.protobuf.GeometryResponse) {}

    stream in file chunks for a geometry file type and stream back results for each geometry encountered
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_GeometryServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GeometryOperationUnary': grpc.unary_unary_rpc_method_handler(
          servicer.GeometryOperationUnary,
          request_deserializer=epl_dot_protobuf_dot_geometry__pb2.GeometryRequest.FromString,
          response_serializer=epl_dot_protobuf_dot_geometry__pb2.GeometryResponse.SerializeToString,
      ),
      'GeometryOperationBiStream': grpc.stream_stream_rpc_method_handler(
          servicer.GeometryOperationBiStream,
          request_deserializer=epl_dot_protobuf_dot_geometry__pb2.GeometryRequest.FromString,
          response_serializer=epl_dot_protobuf_dot_geometry__pb2.GeometryResponse.SerializeToString,
      ),
      'GeometryOperationBiStreamFlow': grpc.stream_stream_rpc_method_handler(
          servicer.GeometryOperationBiStreamFlow,
          request_deserializer=epl_dot_protobuf_dot_geometry__pb2.GeometryRequest.FromString,
          response_serializer=epl_dot_protobuf_dot_geometry__pb2.GeometryResponse.SerializeToString,
      ),
      'FileOperationBiStreamFlow': grpc.stream_stream_rpc_method_handler(
          servicer.FileOperationBiStreamFlow,
          request_deserializer=epl_dot_protobuf_dot_geometry__pb2.FileRequestChunk.FromString,
          response_serializer=epl_dot_protobuf_dot_geometry__pb2.GeometryResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'epl.protobuf.GeometryService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: epl/protobuf/stac.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from epl.protobuf import geometry_pb2 as epl_dot_protobuf_dot_geometry__pb2
from epl.protobuf import query_pb2 as epl_dot_protobuf_dot_query__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='epl/protobuf/stac.proto',
  package='epl.protobuf',
  syntax='proto3',
  serialized_options=_b('\n\020com.epl.protobufB\tStacProtoP\001Z+github.com/geo-grpc/api/golang/epl/protobuf\242\002\004STPB'),
  serialized_pb=_b('\n\x17\x65pl/protobuf/stac.proto\x12\x0c\x65pl.protobuf\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x19google/protobuf/any.proto\x1a\x1b\x65pl/protobuf/geometry.proto\x1a\x18\x65pl/protobuf/query.proto\"\x89\x04\n\x11StacSearchRequest\x12%\n\x02id\x18\x01 \x01(\x0b\x32\x19.epl.protobuf.StringField\x12,\n\x08geometry\x18\x02 \x01(\x0b\x32\x1a.epl.protobuf.GeometryData\x12(\n\x04\x62\x62ox\x18\x03 \x01(\x0b\x32\x1a.epl.protobuf.EnvelopeData\x12\x37\n\x10geometry_request\x18\x04 \x01(\x0b\x32\x1d.epl.protobuf.GeometryRequest\x12\x30\n\x12properties_request\x18\x05 \x01(\x0b\x32\x14.google.protobuf.Any\x12.\n\x08\x64\x61tetime\x18\x06 \x01(\x0b\x32\x1c.epl.protobuf.TimestampField\x12.\n\x08observed\x18\x07 \x01(\x0b\x32\x1c.epl.protobuf.TimestampField\x12/\n\tprocessed\x18\x08 \x01(\x0b\x32\x1c.epl.protobuf.TimestampField\x12-\n\x07updated\x18\t \x01(\x0b\x32\x1c.epl.protobuf.TimestampField\x12+\n\neo_request\x18\n \x01(\x0b\x32\x17.epl.protobuf.EoRequest\x12\r\n\x05limit\x18\x0b \x01(\r\x12\x0e\n\x06offset\x18\x0c \x01(\x04\"\x90\x02\n\x0b\x42\x61ndDetails\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x63ommon_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12(\n\x03gsd\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12-\n\x08\x61\x63\x63uracy\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x36\n\x11\x63\x65nter_wavelength\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x38\n\x13\x66ull_width_half_max\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"\x80\x02\n\x05\x41sset\x12\x0c\n\x04href\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\'\n\x08\x65o_bands\x18\x03 \x01(\x0e\x32\x15.epl.protobuf.Eo.Band\x12+\n\nasset_type\x18\x04 \x01(\x0e\x32\x17.epl.protobuf.AssetType\x12\x33\n\x0e\x63loud_platform\x18\x05 \x01(\x0e\x32\x1b.epl.protobuf.CloudPlatform\x12\x14\n\x0c\x62ucket_owner\x18\x06 \x01(\t\x12\x15\n\rbucket_region\x18\x07 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x08 \x01(\t\x12\x13\n\x0bobject_path\x18\t \x01(\t\"\xb4\x04\n\x0cStacMetadata\x12\n\n\x02id\x18\x01 \x01(\t\x12,\n\x08geometry\x18\x03 \x01(\x0b\x32\x1a.epl.protobuf.GeometryData\x12(\n\x04\x62\x62ox\x18\x04 \x01(\x0b\x32\x1a.epl.protobuf.EnvelopeData\x12(\n\nproperties\x18\x05 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x36\n\x06\x61ssets\x18\x07 \x03(\x0b\x32&.epl.protobuf.StacMetadata.AssetsEntry\x12,\n\x08\x64\x61tetime\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08observed\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tprocessed\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07updated\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x02\x65o\x18\r \x01(\x0b\x32\x10.epl.protobuf.Eo\x12\x1e\n\x03sar\x18\x0e \x01(\x0b\x32\x11.epl.protobuf.Sar\x12\x1e\n\x03\x64tr\x18\x0f \x01(\x0b\x32\x11.epl.protobuf.Dtr\x1a\x42\n\x0b\x41ssetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.epl.protobuf.Asset:\x02\x38\x01J\x04\x08\x06\x10\x07\"Y\n\x03\x44tr\x12)\n\x05start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"J\n\x12StacUpsertResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61ta_id\x18\x03 \x01(\t\"\x99\x01\n\x03Sar\x12,\n\x08platform\x18\x01 \x01(\x0e\x32\x1a.epl.protobuf.Sar.Platform\">\n\x08Platform\x12\x14\n\x10UNKNOWN_PLATFORM\x10\x00\x12\x0b\n\x07\x45NVISAT\x10\x01\x12\x0f\n\x0bSENTINEL_1A\x10\x02\"$\n\nInstrument\x12\x16\n\x12UNKNOWN_INSTRUMENT\x10\x00\"\x89\x08\n\x02\x45o\x12\x0c\n\x04\x65psg\x18\x01 \x01(\r\x12+\n\x08platform\x18\x02 \x01(\x0e\x32\x19.epl.protobuf.Eo.Platform\x12/\n\ninstrument\x18\x03 \x01(\x0e\x32\x1b.epl.protobuf.Eo.Instrument\x12\x35\n\rconstellation\x18\x04 \x01(\x0e\x32\x1e.epl.protobuf.Eo.Constellation\x12\x30\n\x0bsun_azimuth\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x32\n\rsun_elevation\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12(\n\x03gsd\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12.\n\toff_nadir\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12,\n\x07\x61zimuth\x18\t \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\x0b\x63loud_cover\x18\n \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12$\n\x05\x62\x61nds\x18\x0b \x01(\x0e\x32\x15.epl.protobuf.Eo.Band\"\xb9\x01\n\x08Platform\x12\x14\n\x10UNKNOWN_PLATFORM\x10\x00\x12\r\n\tLANDSAT_1\x10\x02\x12\r\n\tLANDSAT_2\x10\x04\x12\r\n\tLANDSAT_3\x10\x08\x12\x0f\n\x0bLANDSAT_123\x10\x0e\x12\r\n\tLANDSAT_4\x10\x10\x12\r\n\tLANDSAT_5\x10 \x12\x0e\n\nLANDSAT_45\x10\x30\x12\r\n\tLANDSAT_7\x10@\x12\x0e\n\tLANDSAT_8\x10\x80\x01\x12\x0c\n\x07SWIFT_2\x10\x80\x02\"B\n\nInstrument\x12\x16\n\x12UNKNOWN_INSTRUMENT\x10\x00\x12\x07\n\x03OLI\x10\x02\x12\x08\n\x04TIRS\x10\x04\x12\t\n\x05POM_1\x10\x08\"V\n\rConstellation\x12\x19\n\x15UNKNOWN_CONSTELLATION\x10\x00\x12\x0b\n\x07LANDSAT\x10\x02\x12\x08\n\x04NAIP\x10\x04\x12\x08\n\x04PNOA\x10\x08\x12\t\n\x05SWIFT\x10\x10\"\xc1\x01\n\x04\x42\x61nd\x12\x10\n\x0cUNKNOWN_BAND\x10\x00\x12\x0b\n\x07\x43OASTAL\x10\x02\x12\x08\n\x04\x42LUE\x10\x04\x12\t\n\x05GREEN\x10\x08\x12\x07\n\x03RED\x10\x10\x12\x07\n\x03RGB\x10\x1c\x12\x11\n\rNEAR_INFRARED\x10 \x12\t\n\x05RGBIR\x10<\x12\x0b\n\x07SWIR_16\x10@\x12\x0c\n\x07SWIR_22\x10\x80\x01\x12\x11\n\x0cPANCHROMATIC\x10\x80\x02\x12\x0b\n\x06\x43IRRUS\x10\x80\x04\x12\x0c\n\x07LWIR_11\x10\x80\x08\x12\x0c\n\x07LWIR_12\x10\x80\x10\"\xe2\x03\n\tEoRequest\x12\x0c\n\x04\x65psg\x18\x01 \x01(\x05\x12+\n\x08platform\x18\x02 \x01(\x0e\x32\x19.epl.protobuf.Eo.Platform\x12/\n\ninstrument\x18\x03 \x01(\x0e\x32\x1b.epl.protobuf.Eo.Instrument\x12\x35\n\rconstellation\x18\x04 \x01(\x0e\x32\x1e.epl.protobuf.Eo.Constellation\x12-\n\x0bsun_azimuth\x18\x05 \x01(\x0b\x32\x18.epl.protobuf.FloatField\x12/\n\rsun_elevation\x18\x06 \x01(\x0b\x32\x18.epl.protobuf.FloatField\x12%\n\x03gsd\x18\x07 \x01(\x0b\x32\x18.epl.protobuf.FloatField\x12+\n\toff_nadir\x18\x08 \x01(\x0b\x32\x18.epl.protobuf.FloatField\x12)\n\x07\x61zimuth\x18\t \x01(\x0b\x32\x18.epl.protobuf.FloatField\x12-\n\x0b\x63loud_cover\x18\n \x01(\x0b\x32\x18.epl.protobuf.FloatField\x12$\n\x05\x62\x61nds\x18\x0b \x01(\x0e\x32\x15.epl.protobuf.Eo.Band*\x94\x01\n\tAssetType\x12\x11\n\rUNKNOWN_ASSET\x10\x00\x12\x08\n\x04JPEG\x10\x01\x12\x0b\n\x07GEOTIFF\x10\x02\x12\x08\n\x04LERC\x10\x03\x12\x07\n\x03MRF\x10\x04\x12\x0b\n\x07MRF_IDX\x10\x05\x12\x0b\n\x07MRF_XML\x10\x06\x12\x0e\n\nCO_GEOTIFF\x10\x07\x12\x07\n\x03RAW\x10\x08\x12\r\n\tTHUMBNAIL\x10\t\x12\x08\n\x04TIFF\x10\n*H\n\rCloudPlatform\x12\x1a\n\x16UNKNOWN_CLOUD_PLATFORM\x10\x00\x12\x07\n\x03\x41WS\x10\x01\x12\x07\n\x03GCP\x10\x02\x12\t\n\x05\x41ZURE\x10\x03\x42S\n\x10\x63om.epl.protobufB\tStacProtoP\x01Z+github.com/geo-grpc/api/golang/epl/protobuf\xa2\x02\x04STPBb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,epl_dot_protobuf_dot_geometry__pb2.DESCRIPTOR,epl_dot_protobuf_dot_query__pb2.DESCRIPTOR,])

_ASSETTYPE = _descriptor.EnumDescriptor(
  name='AssetType',
  full_name='epl.protobuf.AssetType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ASSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JPEG', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEOTIFF', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LERC', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MRF', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MRF_IDX', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MRF_XML', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CO_GEOTIFF', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAW', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THUMBNAIL', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIFF', index=10, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3658,
  serialized_end=3806,
)
_sym_db.RegisterEnumDescriptor(_ASSETTYPE)

AssetType = enum_type_wrapper.EnumTypeWrapper(_ASSETTYPE)
_CLOUDPLATFORM = _descriptor.EnumDescriptor(
  name='CloudPlatform',
  full_name='epl.protobuf.CloudPlatform',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_CLOUD_PLATFORM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AWS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GCP', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AZURE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3808,
  serialized_end=3880,
)
_sym_db.RegisterEnumDescriptor(_CLOUDPLATFORM)

CloudPlatform = enum_type_wrapper.EnumTypeWrapper(_CLOUDPLATFORM)
UNKNOWN_ASSET = 0
JPEG = 1
GEOTIFF = 2
LERC = 3
MRF = 4
MRF_IDX = 5
MRF_XML = 6
CO_GEOTIFF = 7
RAW = 8
THUMBNAIL = 9
TIFF = 10
UNKNOWN_CLOUD_PLATFORM = 0
AWS = 1
GCP = 2
AZURE = 3


_SAR_PLATFORM = _descriptor.EnumDescriptor(
  name='Platform',
  full_name='epl.protobuf.Sar.Platform',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_PLATFORM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENVISAT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENTINEL_1A', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2034,
  serialized_end=2096,
)
_sym_db.RegisterEnumDescriptor(_SAR_PLATFORM)

_SAR_INSTRUMENT = _descriptor.EnumDescriptor(
  name='Instrument',
  full_name='epl.protobuf.Sar.Instrument',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_INSTRUMENT', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2098,
  serialized_end=2134,
)
_sym_db.RegisterEnumDescriptor(_SAR_INSTRUMENT)

_EO_PLATFORM = _descriptor.EnumDescriptor(
  name='Platform',
  full_name='epl.protobuf.Eo.Platform',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_PLATFORM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_1', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_2', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_3', index=3, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_123', index=4, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_4', index=5, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_5', index=6, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_45', index=7, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_7', index=8, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT_8', index=9, number=128,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIFT_2', index=10, number=256,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2633,
  serialized_end=2818,
)
_sym_db.RegisterEnumDescriptor(_EO_PLATFORM)

_EO_INSTRUMENT = _descriptor.EnumDescriptor(
  name='Instrument',
  full_name='epl.protobuf.Eo.Instrument',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_INSTRUMENT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OLI', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIRS', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POM_1', index=3, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2820,
  serialized_end=2886,
)
_sym_db.RegisterEnumDescriptor(_EO_INSTRUMENT)

_EO_CONSTELLATION = _descriptor.EnumDescriptor(
  name='Constellation',
  full_name='epl.protobuf.Eo.Constellation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_CONSTELLATION', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDSAT', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAIP', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PNOA', index=3, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIFT', index=4, number=16,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2888,
  serialized_end=2974,
)
_sym_db.RegisterEnumDescriptor(_EO_CONSTELLATION)

_EO_BAND = _descriptor.EnumDescriptor(
  name='Band',
  full_name='epl.protobuf.Eo.Band',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_BAND', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COASTAL', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLUE', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREEN', index=3, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RED', index=4, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RGB', index=5, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEAR_INFRARED', index=6, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RGBIR', index=7, number=60,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIR_16', index=8, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIR_22', index=9, number=128,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PANCHROMATIC', index=10, number=256,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CIRRUS', index=11, number=512,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LWIR_11', index=12, number=1024,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LWIR_12', index=13, number=2048,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2977,
  serialized_end=3170,
)
_sym_db.RegisterEnumDescriptor(_EO_BAND)


_STACSEARCHREQUEST = _descriptor.Descriptor(
  name='StacSearchRequest',
  full_name='epl.protobuf.StacSearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='epl.protobuf.StacSearchRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='epl.protobuf.StacSearchRequest.geometry', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bbox', full_name='epl.protobuf.StacSearchRequest.bbox', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geometry_request', full_name='epl.protobuf.StacSearchRequest.geometry_request', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties_request', full_name='epl.protobuf.StacSearchRequest.properties_request', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datetime', full_name='epl.protobuf.StacSearchRequest.datetime', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='observed', full_name='epl.protobuf.StacSearchRequest.observed', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processed', full_name='epl.protobuf.StacSearchRequest.processed', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated', full_name='epl.protobuf.StacSearchRequest.updated', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eo_request', full_name='epl.protobuf.StacSearchRequest.eo_request', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='epl.protobuf.StacSearchRequest.limit', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='epl.protobuf.StacSearchRequest.offset', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=710,
)


_BANDDETAILS = _descriptor.Descriptor(
  name='BandDetails',
  full_name='epl.protobuf.BandDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='epl.protobuf.BandDetails.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='common_name', full_name='epl.protobuf.BandDetails.common_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='epl.protobuf.BandDetails.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gsd', full_name='epl.protobuf.BandDetails.gsd', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='epl.protobuf.BandDetails.accuracy', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='center_wavelength', full_name='epl.protobuf.BandDetails.center_wavelength', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_width_half_max', full_name='epl.protobuf.BandDetails.full_width_half_max', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=713,
  serialized_end=985,
)


_ASSET = _descriptor.Descriptor(
  name='Asset',
  full_name='epl.protobuf.Asset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='href', full_name='epl.protobuf.Asset.href', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='epl.protobuf.Asset.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eo_bands', full_name='epl.protobuf.Asset.eo_bands', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset_type', full_name='epl.protobuf.Asset.asset_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cloud_platform', full_name='epl.protobuf.Asset.cloud_platform', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket_owner', full_name='epl.protobuf.Asset.bucket_owner', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket_region', full_name='epl.protobuf.Asset.bucket_region', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='epl.protobuf.Asset.bucket', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_path', full_name='epl.protobuf.Asset.object_path', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=988,
  serialized_end=1244,
)


_STACMETADATA_ASSETSENTRY = _descriptor.Descriptor(
  name='AssetsEntry',
  full_name='epl.protobuf.StacMetadata.AssetsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='epl.protobuf.StacMetadata.AssetsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='epl.protobuf.StacMetadata.AssetsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1739,
  serialized_end=1805,
)

_STACMETADATA = _descriptor.Descriptor(
  name='StacMetadata',
  full_name='epl.protobuf.StacMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='epl.protobuf.StacMetadata.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='epl.protobuf.StacMetadata.geometry', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bbox', full_name='epl.protobuf.StacMetadata.bbox', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties', full_name='epl.protobuf.StacMetadata.properties', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assets', full_name='epl.protobuf.StacMetadata.assets', index=4,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datetime', full_name='epl.protobuf.StacMetadata.datetime', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='observed', full_name='epl.protobuf.StacMetadata.observed', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processed', full_name='epl.protobuf.StacMetadata.processed', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated', full_name='epl.protobuf.StacMetadata.updated', index=8,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eo', full_name='epl.protobuf.StacMetadata.eo', index=9,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sar', full_name='epl.protobuf.StacMetadata.sar', index=10,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dtr', full_name='epl.protobuf.StacMetadata.dtr', index=11,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STACMETADATA_ASSETSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1247,
  serialized_end=1811,
)


_DTR = _descriptor.Descriptor(
  name='Dtr',
  full_name='epl.protobuf.Dtr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='epl.protobuf.Dtr.start', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='epl.protobuf.Dtr.end', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1813,
  serialized_end=1902,
)


_STACUPSERTRESPONSE = _descriptor.Descriptor(
  name='StacUpsertResponse',
  full_name='epl.protobuf.StacUpsertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='epl.protobuf.StacUpsertResponse.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status_code', full_name='epl.protobuf.StacUpsertResponse.status_code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_id', full_name='epl.protobuf.StacUpsertResponse.data_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1904,
  serialized_end=1978,
)


_SAR = _descriptor.Descriptor(
  name='Sar',
  full_name='epl.protobuf.Sar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='platform', full_name='epl.protobuf.Sar.platform', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SAR_PLATFORM,
    _SAR_INSTRUMENT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1981,
  serialized_end=2134,
)


_EO = _descriptor.Descriptor(
  name='Eo',
  full_name='epl.protobuf.Eo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='epsg', full_name='epl.protobuf.Eo.epsg', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platform', full_name='epl.protobuf.Eo.platform', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument', full_name='epl.protobuf.Eo.instrument', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='constellation', full_name='epl.protobuf.Eo.constellation', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sun_azimuth', full_name='epl.protobuf.Eo.sun_azimuth', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sun_elevation', full_name='epl.protobuf.Eo.sun_elevation', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gsd', full_name='epl.protobuf.Eo.gsd', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='off_nadir', full_name='epl.protobuf.Eo.off_nadir', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='azimuth', full_name='epl.protobuf.Eo.azimuth', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cloud_cover', full_name='epl.protobuf.Eo.cloud_cover', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bands', full_name='epl.protobuf.Eo.bands', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EO_PLATFORM,
    _EO_INSTRUMENT,
    _EO_CONSTELLATION,
    _EO_BAND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2137,
  serialized_end=3170,
)


_EOREQUEST = _descriptor.Descriptor(
  name='EoRequest',
  full_name='epl.protobuf.EoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='epsg', full_name='epl.protobuf.EoRequest.epsg', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platform', full_name='epl.protobuf.EoRequest.platform', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrument', full_name='epl.protobuf.EoRequest.instrument', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='constellation', full_name='epl.protobuf.EoRequest.constellation', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sun_azimuth', full_name='epl.protobuf.EoRequest.sun_azimuth', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sun_elevation', full_name='epl.protobuf.EoRequest.sun_elevation', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gsd', full_name='epl.protobuf.EoRequest.gsd', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='off_nadir', full_name='epl.protobuf.EoRequest.off_nadir', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='azimuth', full_name='epl.protobuf.EoRequest.azimuth', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cloud_cover', full_name='epl.protobuf.EoRequest.cloud_cover', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bands', full_name='epl.protobuf.EoRequest.bands', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3173,
  serialized_end=3655,
)

_STACSEARCHREQUEST.fields_by_name['id'].message_type = epl_dot_protobuf_dot_query__pb2._STRINGFIELD
_STACSEARCHREQUEST.fields_by_name['geometry'].message_type = epl_dot_protobuf_dot_geometry__pb2._GEOMETRYDATA
_STACSEARCHREQUEST.fields_by_name['bbox'].message_type = epl_dot_protobuf_dot_geometry__pb2._ENVELOPEDATA
_STACSEARCHREQUEST.fields_by_name['geometry_request'].message_type = epl_dot_protobuf_dot_geometry__pb2._GEOMETRYREQUEST
_STACSEARCHREQUEST.fields_by_name['properties_request'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STACSEARCHREQUEST.fields_by_name['datetime'].message_type = epl_dot_protobuf_dot_query__pb2._TIMESTAMPFIELD
_STACSEARCHREQUEST.fields_by_name['observed'].message_type = epl_dot_protobuf_dot_query__pb2._TIMESTAMPFIELD
_STACSEARCHREQUEST.fields_by_name['processed'].message_type = epl_dot_protobuf_dot_query__pb2._TIMESTAMPFIELD
_STACSEARCHREQUEST.fields_by_name['updated'].message_type = epl_dot_protobuf_dot_query__pb2._TIMESTAMPFIELD
_STACSEARCHREQUEST.fields_by_name['eo_request'].message_type = _EOREQUEST
_BANDDETAILS.fields_by_name['gsd'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_BANDDETAILS.fields_by_name['accuracy'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_BANDDETAILS.fields_by_name['center_wavelength'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_BANDDETAILS.fields_by_name['full_width_half_max'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_ASSET.fields_by_name['eo_bands'].enum_type = _EO_BAND
_ASSET.fields_by_name['asset_type'].enum_type = _ASSETTYPE
_ASSET.fields_by_name['cloud_platform'].enum_type = _CLOUDPLATFORM
_STACMETADATA_ASSETSENTRY.fields_by_name['value'].message_type = _ASSET
_STACMETADATA_ASSETSENTRY.containing_type = _STACMETADATA
_STACMETADATA.fields_by_name['geometry'].message_type = epl_dot_protobuf_dot_geometry__pb2._GEOMETRYDATA
_STACMETADATA.fields_by_name['bbox'].message_type = epl_dot_protobuf_dot_geometry__pb2._ENVELOPEDATA
_STACMETADATA.fields_by_name['properties'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STACMETADATA.fields_by_name['assets'].message_type = _STACMETADATA_ASSETSENTRY
_STACMETADATA.fields_by_name['datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STACMETADATA.fields_by_name['observed'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STACMETADATA.fields_by_name['processed'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STACMETADATA.fields_by_name['updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STACMETADATA.fields_by_name['eo'].message_type = _EO
_STACMETADATA.fields_by_name['sar'].message_type = _SAR
_STACMETADATA.fields_by_name['dtr'].message_type = _DTR
_DTR.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DTR.fields_by_name['end'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SAR.fields_by_name['platform'].enum_type = _SAR_PLATFORM
_SAR_PLATFORM.containing_type = _SAR
_SAR_INSTRUMENT.containing_type = _SAR
_EO.fields_by_name['platform'].enum_type = _EO_PLATFORM
_EO.fields_by_name['instrument'].enum_type = _EO_INSTRUMENT
_EO.fields_by_name['constellation'].enum_type = _EO_CONSTELLATION
_EO.fields_by_name['sun_azimuth'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_EO.fields_by_name['sun_elevation'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_EO.fields_by_name['gsd'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_EO.fields_by_name['off_nadir'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_EO.fields_by_name['azimuth'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_EO.fields_by_name['cloud_cover'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_EO.fields_by_name['bands'].enum_type = _EO_BAND
_EO_PLATFORM.containing_type = _EO
_EO_INSTRUMENT.containing_type = _EO
_EO_CONSTELLATION.containing_type = _EO
_EO_BAND.containing_type = _EO
_EOREQUEST.fields_by_name['platform'].enum_type = _EO_PLATFORM
_EOREQUEST.fields_by_name['instrument'].enum_type = _EO_INSTRUMENT
_EOREQUEST.fields_by_name['constellation'].enum_type = _EO_CONSTELLATION
_EOREQUEST.fields_by_name['sun_azimuth'].message_type = epl_dot_protobuf_dot_query__pb2._FLOATFIELD
_EOREQUEST.fields_by_name['sun_elevation'].message_type = epl_dot_protobuf_dot_query__pb2._FLOATFIELD
_EOREQUEST.fields_by_name['gsd'].message_type = epl_dot_protobuf_dot_query__pb2._FLOATFIELD
_EOREQUEST.fields_by_name['off_nadir'].message_type = epl_dot_protobuf_dot_query__pb2._FLOATFIELD
_EOREQUEST.fields_by_name['azimuth'].message_type = epl_dot_protobuf_dot_query__pb2._FLOATFIELD
_EOREQUEST.fields_by_name['cloud_cover'].message_type = epl_dot_protobuf_dot_query__pb2._FLOATFIELD
_EOREQUEST.fields_by_name['bands'].enum_type = _EO_BAND
DESCRIPTOR.message_types_by_name['StacSearchRequest'] = _STACSEARCHREQUEST
DESCRIPTOR.message_types_by_name['BandDetails'] = _BANDDETAILS
DESCRIPTOR.message_types_by_name['Asset'] = _ASSET
DESCRIPTOR.message_types_by_name['StacMetadata'] = _STACMETADATA
DESCRIPTOR.message_types_by_name['Dtr'] = _DTR
DESCRIPTOR.message_types_by_name['StacUpsertResponse'] = _STACUPSERTRESPONSE
DESCRIPTOR.message_types_by_name['Sar'] = _SAR
DESCRIPTOR.message_types_by_name['Eo'] = _EO
DESCRIPTOR.message_types_by_name['EoRequest'] = _EOREQUEST
DESCRIPTOR.enum_types_by_name['AssetType'] = _ASSETTYPE
DESCRIPTOR.enum_types_by_name['CloudPlatform'] = _CLOUDPLATFORM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StacSearchRequest = _reflection.GeneratedProtocolMessageType('StacSearchRequest', (_message.Message,), dict(
  DESCRIPTOR = _STACSEARCHREQUEST,
  __module__ = 'epl.protobuf.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.StacSearchRequest)
  ))
_sym_db.RegisterMessage(StacSearchRequest)

BandDetails = _reflection.GeneratedProtocolMessageType('BandDetails', (_message.Message,), dict(
  DESCRIPTOR = _BANDDETAILS,
  __module__ = 'epl.protobuf.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.BandDetails)
  ))
_sym_db.RegisterMessage(BandDetails)

Asset = _reflection.GeneratedProtocolMessageType('Asset', (_message.Message,), dict(
  DESCRIPTOR = _ASSET,
  __module__ = 'epl.protobuf.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.Asset)
  ))
_sym_db.RegisterMessage(Asset)

StacMetadata = _reflection.GeneratedProtocolMessageType('StacMetadata', (_message.Message,), dict(

  AssetsEntry = _reflection.GeneratedProtocolMessageType('AssetsEntry', (_message.Message,), dict(
    DESCRIPTOR = _STACMETADATA_ASSETSENTRY,
    __module__ = 'epl.protobuf.stac_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.StacMetadata.AssetsEntry)
    ))
  ,
  DESCRIPTOR = _STACMETADATA,
  __module__ = 'epl.protobuf.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.StacMetadata)
  ))
_sym_db.RegisterMessage(StacMetadata)
_sym_db.RegisterMessage(StacMetadata.AssetsEntry)

Dtr = _reflection.GeneratedProtocolMessageType('Dtr', (_message.Message,), dict(
  DESCRIPTOR = _DTR,
  __module__ = 'epl.protobuf.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.Dtr)
  ))
_sym_db.RegisterMessage(Dtr)

StacUpsertResponse = _reflection.GeneratedProtocolMessageType('StacUpsertResponse', (_message.Message,), dict(
  DESCRIPTOR = _STACUPSERTRESPONSE,
  __module__ = 'epl.protobuf.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.StacUpsertResponse)
  ))
_sym_db.RegisterMessage(StacUpsertResponse)

Sar = _reflection.GeneratedProtocolMessageType('Sar', (_message.Message,), dict(
  DESCRIPTOR = _SAR,
  __module__ = 'epl.protobuf.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.Sar)
  ))
_sym_db.RegisterMessage(Sar)

Eo = _reflection.GeneratedProtocolMessageType('Eo', (_message.Message,), dict(
  DESCRIPTOR = _EO,
  __module__ = 'epl.protobuf.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.Eo)
  ))
_sym_db.RegisterMessage(Eo)

EoRequest = _reflection.GeneratedProtocolMessageType('EoRequest', (_message.Message,), dict(
  DESCRIPTOR = _EOREQUEST,
  __module__ = 'epl.protobuf.stac_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.EoRequest)
  ))
_sym_db.RegisterMessage(EoRequest)


DESCRIPTOR._options = None
_STACMETADATA_ASSETSENTRY._options = None
# @@protoc_insertion_point(module_scope)
